
--The example in this section uses the full-text index on the Production.Document table. For an example that creates this index, see "Example C" in CREATE FULLTEXT INDEX (Transact-SQL).

USE AdventureWorks2008R2;
GO 	

DROP FULLTEXT INDEX ON [Production].[Document]
go

CREATE FULLTEXT INDEX ON [Production].[Document](
[Document] TYPE COLUMN [FileExtension] LANGUAGE [English], 
[DocumentSummary] LANGUAGE [English])
KEY INDEX [PK_Document_DocumentNode] ON ([AW2008FullTextCatalog], FILEGROUP [PRIMARY])
WITH (CHANGE_TRACKING = AUTO, STOPLIST = SYSTEM)
go

-- Set up the search property list 
CREATE SEARCH PROPERTY LIST DocumentProperties;
GO
ALTER SEARCH PROPERTY LIST DocumentProperties
   ADD 'Title' 
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 2, 
      PROPERTY_DESCRIPTION = 'System.Title - Title of the item.' );
ALTER SEARCH PROPERTY LIST DocumentPropertyList 
    ADD 'Author'
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 4, 
      PROPERTY_DESCRIPTION = 'System.Author - Author or authors of the item.' );
ALTER SEARCH PROPERTY LIST DocumentProperties 
    ADD 'Tags'
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 5, 
      PROPERTY_DESCRIPTION = 'System.Keywords - Keywords (Tags) of the item.' );
GO

ALTER FULLTEXT INDEX ON Production.Document 
   SET SEARCH PROPERTY LIST DocumentProperties
   WITH NO POPULATION; 
GO

ALTER FULLTEXT INDEX ON Production.Document 
   START FULL POPULATION;
GO

select objectpropertyex(object_id('Production.Document'),'TableFulltextPopulateStatus')

-- metadata
select * from sys.registered_search_properties 
select * from sys.registered_search_property_lists
select * from sys.dm_fts_index_keywords_by_property(
 DB_ID('AdventureWorks2008R2'), 
 OBJECT_ID('Production.Document'))

-- search by property
SELECT Document FROM Production.Document
  WHERE CONTAINS(PROPERTY(Document,'Title'), 'Maintenance OR Repair');
GO

-- search property plus content
SELECT Document FROM Production.Document
  WHERE CONTAINS(Document, 'Maintenance OR Repair');
GO

--DROP SEARCH PROPERTY LIST DocumentProperties;

select * from sys.dm_fts_index_keywords(db_id(), object_id('Production.Document'))
order by document_count desc
go